/* Developed for Lenovo Educational Board Pass 3
   © Lenovo Created by Joshua Grosser
   v. 2.0 */

#include <Adafruit_NeoPixel.h>

#define NEOPIXEL_PIN 1 // Neopixel is on pin 1
#define NEOPIXEL_COUNT 1 // There is only 1 RGB LED on DOS
#define NEOPIXEL_INDEX 0 // RGB LED is at index 0

#define MIN_COLOR_LIMIT 0 // Min R,G,B value
#define MAX_COLOR_LIMIT 255 // Max R,G,B value

#define DELAYVAL 500 // Time (in milliseconds) to pause between pixels
// Create a NeoPixel object
Adafruit_NeoPixel Pixel(NEOPIXEL_COUNT, NEOPIXEL_PIN, NEO_GRB + NEO_KHZ800);

void setup() {
  // Set baud rate on the serial port
  Serial.begin(115200);
  Serial.println("HPE ESP32 Dos says Hello!");

  // Initialize the NeoPixel object
  Pixel.begin();

  // Set all pixel colors to OFF
  Pixel.clear();
  Pixel.show();

  // Show syntax for providing R,G,B values
  Serial.println();
  Serial.println();
  Serial.println("Type comma separated values [0...255]");
  Serial.println("for R, G and B in the text window above");
  Serial.println("and then press ENTER.");
  Serial.println("Example: 128,0,128<ENTER> to glow purple!");
  Serial.println();
}

void loop() {
  // Read values from the serial port
  while(Serial.available() > 0)
  {
    // separate integer values by comma
    int red = Serial.parseInt();
    int green = Serial.parseInt();
    int blue = Serial.parseInt();

    // A newline character indicates end of input
    if(Serial.read() == '\n')
    {
      // Adjust the values if out of range
      red = constrain(red, MIN_COLOR_LIMIT, MAX_COLOR_LIMIT);
      green = constrain(green, MIN_COLOR_LIMIT, MAX_COLOR_LIMIT);
      blue = constrain(blue, MIN_COLOR_LIMIT, MAX_COLOR_LIMIT);

      // Display the color values to the serial
      Serial.print("Setting the RGB LED with");
      Serial.print(" R=");
      Serial.print(red, DEC);
      Serial.print(" G=");
      Serial.print(green, DEC);
      Serial.print(" B=");
      Serial.println(blue, DEC);

      // setPixelColor() takes RGB values, from 0,0,0 up to 255,255,255
      Pixel.setPixelColor(NEOPIXEL_INDEX, red, green, blue);

      // Push the color data to the hardware
      Pixel.show();
    }
  }
}
